@@ -1,12 +1,13 @@
 package Text::Table::Tiny;
-$Text::Table::Tiny::VERSION = '0.05_01'; # TRIAL
+$Text::Table::Tiny::VERSION = '0.05_02'; # TRIAL
 
-$Text::Table::Tiny::VERSION = '0.0501';use 5.010;
+$Text::Table::Tiny::VERSION = '0.0502';use 5.010;
 use strict;
 use warnings;
 use utf8;
-use Carp qw/ croak /;
 use parent 'Exporter';
+use Carp         qw/ croak /;
+use Ref::Util    qw/ is_arrayref is_ref /;
 our @EXPORT_OK = qw/ generate_table /;
 
 # Legacy package globals, that can be used to customise the look.
@@ -44,8 +45,16 @@ sub generate_table
     }
 
     my $header;
-    my $astring = $param{align} // 'l' x int(@widths);
-    my @align   = split('', $astring);
+    my @align;
+    if (defined $param{align}) {
+        @align = is_arrayref($param{align})
+               ? @{ $param{align} }
+               : ($param{align}) x int(@widths)
+               ;
+    }
+    else {
+        @align = ('l') x int(@widths);
+    }
 
     $header = shift @rows if $param{header_row};
 
@@ -141,18 +150,18 @@ sub _format_column
     my ($text, $width, $align, $param, $char) = @_;
     my $pad = $param->{compact} ? '' : ' ';
 
-    if ($align eq 'r') {
-        return $pad.' ' x ($width - length($text)).$text.$pad;
+    if ($align eq 'r' || $align eq 'right') {
+        return $pad.' ' x ($width - tty_length($text)).$text.$pad;
     }
-    elsif ($align eq 'c') {
-        my $total_spaces = $width - length($text);
+    elsif ($align eq 'c' || $align eq 'center' || $align eq 'centre') {
+        my $total_spaces = $width - tty_length($text);
         my $left_spaces  = int($total_spaces / 2);
         my $right_spaces = $left_spaces;
         $right_spaces++ if $total_spaces % 2 == 1;
         return $pad.(' ' x $left_spaces).$text.(' ' x $right_spaces).$pad;
     }
     else {
-        return $pad.$text.' ' x ($width - length($text)).$pad;
+        return $pad.$text.' ' x ($width - tty_length($text)).$pad;
     }
 }
 
@@ -164,13 +173,20 @@ sub _calculate_widths
         my @columns = @$row;
         for (my $i = 0; $i < @columns; $i++) {
             next unless defined($columns[$i]);
-            $widths[$i] = length($columns[$i]) if !defined($widths[$i])
-                                              || length($columns[$i]) > $widths[$i];
+            $widths[$i] = tty_length($columns[$i]) if !defined($widths[$i])
+                                                   || tty_length($columns[$i]) > $widths[$i];
         }
     }
     return @widths;
 }
 
+sub tty_length
+{
+    my $string = shift;
+    $string =~ s/\e\[[0-9]+(;[0-9]+)?[ABCDEFGHJKSTfmin]//msg;
+    return length($string);
+}
+
 # Back-compat: 'table' is an alias for 'generate_table', but isn't exported
 *table = \&generate_table;
 
@@ -267,6 +283,8 @@ align
 This takes an array ref with one entry per column,
 to specify the alignment of that column.
 Legal values are 'l', 'c', and 'r'.
+You can also specify a single alignment for all columns.
+ANSI escape codes are handled.
 
 =item *
 
